/testing/guestbin/swan-prep
: > /etc/ipsec.secrets
ipsec start
../../guestbin/wait-until-pluto-started
